realignBamBwa: realignBamBwa

Description Usage Arguments Examples

View source: R/realignBamBwa.R

Description

This function realigns bam files using a defined reference genome and bwa being possible to use paired or single end data (type will be detected automatically)

Usage

1
realignBamBwa(inputFile, ref, outPath, threads, removeOpt)

Arguments

inputFile

Path of the fastq file to align.

ref

Path where the reference genome is save.

outPath

Path where the output of the analysis will be saved.

threads

Number of threads to use in the analysis.

removeOpt

Remove old bam option (yes or no)

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
## Not run: 
inputFile <- 'raw/sample.bam'
ref <- 'ref/hg38.fa'
outPath <- 'rst'
threads <- 2
removeOpt <- 'yes'

realignBamBwa(inputFile, ref, outPath, threads, removeOpt)

## End(Not run)

msubirana/ergWgsTools documentation built on June 8, 2020, 8:07 a.m.