Description Usage Arguments Examples
View source: R/variantCalling.R
Tumor-normal pair somatic variant calling using VarScan2.
1 2 3 4 5 6 7 8 9 10 11 12 | varscan2Calling(
tumor_file,
normal_file,
sample_name,
ref,
out_path,
varscan2,
samtools,
fpfilter,
perl,
bcftools
)
|
tumor_file |
Tumor bam to file to perform the variant calling. |
normal_file |
Normal bam to file to perform the variant calling. |
ref |
Path for the reference genome to use for the alignment (fasta format) and the corresponding indexes generated with bwa index and a dictionary index file generated by CreateSequenceDictionary gatk tool. |
out_path |
Path where the output of the analysis will be saved. |
samtools |
Path of samtools binary. |
perl |
Path of perl executable. |
1 2 3 4 5 6 7 8 9 10 11 | ## Not run:
varscan2Calling(tumor_file = 'raw/sample_tumor.bam',
normal_file = 'raw/sample_normal.bam',
sample_name = 'sample'
ref = 'ref/hg38.fa',
out_path = 'rst',
varscan2 = '/bin/VarScan.v2.4.4.jar',
threads = 2,
samtools = '/bin/samtools')
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.