Description Usage Arguments Examples
View source: R/realignBamBwa.R
This function realigns bam files using a defined reference genome and bwa being possible to use paired or single end data (type will be detected automatically)
1 | realignBamBwa(inputFile, ref, outPath, threads, removeOpt)
|
inputFile |
Path of the fastq file to align. |
ref |
Path where the reference genome is save. |
outPath |
Path where the output of the analysis will be saved. |
threads |
Number of threads to use in the analysis. |
removeOpt |
Remove old bam option (yes or no) |
1 2 3 4 5 6 7 8 9 10 | ## Not run:
inputFile <- 'raw/sample.bam'
ref <- 'ref/hg38.fa'
outPath <- 'rst'
threads <- 2
removeOpt <- 'yes'
realignBamBwa(inputFile, ref, outPath, threads, removeOpt)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.